/*
 * Oprogramowanie stopera zaprojektowanego na potrzeby
 * zawodow Line Follower.
 *
 * Krystian (krystian@elektroda.net)
 * KoNaR
 * http://konar.ict.pwr.wroc.pl/
 */
#include <avr/io.h>
#include <stdlib.h>
#include <util/delay.h>

#include "default/wyswietlacz.h"
#include "default/czasomierz.h"
#include "default/bramka1.h"
#include "default/bramka2.h"
#include "default/usart.h"

/*
 * Wysyla na USART aktualny czas w formacie znakowym cyfra
 * po cyfrze od setnych sekund do minut.
 */
void Wyslij()
{
	for (int k=0;k<5;k++)
		USART_Transmit_char(cyfry[k]+0x30);
}

int main()
{  
	/* ustawianie prescalera na 1 */
	CLKPR &= 0xf0;
	CLKPR |= 0x80;

	/* wyjscia */
	DDRB = 0xff;
	PORTB = 0xff;
	
	DDRD = 0xff;
	DDRD |= (1 << PD6);

	/* wejscia */
	DDRD &= ~((1 << PD3) | (1 << PD2));

	USART_Init(MYUBRR);

	InicjujWyswietlacz();
	UstawCzasomierz();

	/* aktywacja przerwania zewnetrznego */
	EIFR  = 0;
	GIMSK = 0b01000000;
	MCUCR = 0b00001010;
	
	/* wlacz przerwania */
	sei();	

	/*
	 * Po wyslaniu aktualnego czasu na USART przesylany jest
	 * znak 'a' oznaczajacy koniec transmisji.
	 * Po zatrzymaniu zegara, ostatnia transmisja konczona jest
	 * znakiem 'z'.
	 */
	zmierzony_t = 0;
	ObliczCyfry(zmierzony_t);
	Wyslij();
	USART_Transmit_char('a');
	send = 0;

	/*
	 * Po kazdym ustawieniu flagi send na USART wysylany jest
	 * aktualny czas i zerowana jest flaga send.
	 */
	for (;;) 
	{
		if (send==1)
		{
			Wyslij();
			USART_Transmit_char('a');
			if (send != 2) send=0;
		}
		if (send==2)
		{
			for (int x=0;x<5;++x)
			{
				Wyslij();
				USART_Transmit_char('z');
				_delay_ms(1);
			}
			send=0;
		}
	}
	return 0;
}
